searchData={"items":[{"type":"module","title":"LiveViewNative.Stylesheet","doc":"Add LiveView Native Stylesheet to your app\n\nStylesheets are format-specific. The rules for parsing style rules\nare defined in each client library. This library provides support for\ndefining and compiling stylesheets.","ref":"LiveViewNative.Stylesheet.html"},{"type":"module","title":"Configuration - LiveViewNative.Stylesheet","doc":"You must configure your application to know which files to parse class names from.\nLiveView Native Stylesheets borrows the same class name extracting logic as Tailwind:\n\n[Tailwind - Dynamic class names](https://tailwindcss.com/docs/content-configuration#dynamic-class-names)\n\n    config :live_view_native,\n      content: [\n        swiftui: [\n          \"lib/**/*swiftui*\"\n        ],\n        jetpack: [\n          \"lib/**/*jetpack*\"\n        ]\n      ],\n      output: \"priv/static/assets/\"\n\nBecause class names may be shared betweeen different formats you should try to ensure\nthat the `content` pattern for that format is as targetd as possible.\n\nYou can also search dependencies by adding a tuple `{opt_app_name, pattern}` to the list\nfor a format:\n\n    content: [\n      swifti: [\n        \"lib/**/*swiftui*\",\n        {:my_custom_lib, \"lib/**/*swiftui*\"},\n        {:other_lib, [\n          \"lib/**/*swiftui*\",\n          \"priv/**/*swiftui*\"\n        ]}\n      ]\n    ],\n    output: \"priv/static/assets/\"","ref":"LiveViewNative.Stylesheet.html#module-configuration"},{"type":"module","title":"Optional configuration - LiveViewNative.Stylesheet","doc":"By default LiveView Native Stylesheet will emit the most concise format possible.\nIn `dev` mode you may want to expand the formatting and include annotations:\n\n    config :live_view_native_stylesheet,\n      annotations: true,\n      pretty: true\n\nWith annotations tured on the native clients will have more information on how to report\nerors and warnings in its logger.","ref":"LiveViewNative.Stylesheet.html#module-optional-configuration"},{"type":"module","title":"Importing other sheets - LiveViewNative.Stylesheet","doc":"Class names defined in another sheet can be importd into your sheet. The classes will\nbe defined *below* your definitions which gives your classes priority. Search order for a matching\nclass is in the order of the imports defined.\n\n    defmodule MyAppWeb.Style.SwifUI do\n      use LiveViewNative.Stylesheet, :swiftui\n\n      @import LiveViewnative.SwiftUI.UtilityClasses\n    end\n\nTo prevent child sheets from producing their own stylesheet when compiled set `@export` to `true`\n\n    defmodule MyStyleLib.SwiftUI do\n      use LiveViewNative.Stylesheet, :swiftui\n      @export true\n\n      ~SHEET\"\"\"\n        ...\n      \"\"\"\n    end","ref":"LiveViewNative.Stylesheet.html#module-importing-other-sheets"},{"type":"macro","title":"LiveViewNative.Stylesheet.__using__/1","doc":"Using in a module allows for stylesheet compilation\n\n    defmodule MyAppWeb.Style.SwiftUI do\n      use LiveViewNative.Stylesheet, :swiftui\n\n      ~SHEET\"\"\"\n        \"padding:\" <> padding do\n          padding({padding})\n        end\n      \"\"\"\n    end\n\nThe following functions are injected into the module:\n\n  * `compile_ast/1` - takes a list of class names, produces AST as an Elixir map\n  * `compile_string/1` - takes a list of class names, produces a string of the AST.\n  Formatting rules are applied from the `live_view_native_stylesheet` application config.","ref":"LiveViewNative.Stylesheet.html#__using__/1"},{"type":"function","title":"LiveViewNative.Stylesheet.unmatched_handler/2","doc":"","ref":"LiveViewNative.Stylesheet.html#unmatched_handler/2"},{"type":"task","title":"mix lvn.stylesheet.gen","doc":"Generates a new format specific stylesheet\n\n    $ mix lvn.stylesheet gen.live swiftui App","ref":"Mix.Tasks.Lvn.Stylesheet.Gen.html"},{"type":"task","title":"Options - mix lvn.stylesheet.gen","doc":"* `--no-copy` - don't copy the styelsheet module into your application\n* `--no-info` - don't print configuration info","ref":"Mix.Tasks.Lvn.Stylesheet.Gen.html#module-options"},{"type":"task","title":"mix lvn.stylesheet.setup.config","doc":"Configure LiveView Native Stylesheet within a project\n\nThis setup will configure your app and generate stylesheets for each available client\n\n    $ mix lvn.stylesheet.setup.config","ref":"Mix.Tasks.Lvn.Stylesheet.Setup.Config.html"},{"type":"function","title":"Mix.Tasks.Lvn.Stylesheet.Setup.Config.build_changesets/1","doc":"","ref":"Mix.Tasks.Lvn.Stylesheet.Setup.Config.html#build_changesets/1"},{"type":"task","title":"mix lvn.stylesheet.setup.gen","doc":"Setup Generators for LiveView Native Stylesheet within a project\n\nThis setup will configure your app and generate stylesheets for each available client\n\n    $ mix lvn.stylesheet.setup.gen","ref":"Mix.Tasks.Lvn.Stylesheet.Setup.Gen.html"},{"type":"extras","title":"LiveViewNativeStylesheet","doc":"# LiveViewNativeStylesheet\n\nStylesheet primitives for LiveView Native\n\nThe library is usually the dependency of another high level lib","ref":"readme.html"},{"type":"extras","title":"Installation - LiveViewNativeStylesheet","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `live_view_native_stylesheet` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:live_view_native_stylesheet, \"~> 0.3.0-rc.4\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - LiveViewNativeStylesheet","doc":"All LiveViewNative Stylesheet output can be configured. By default\nannotations and pretty printing is enabled. If you want smaller outputs\nfor `prod` environments you'll need these options off:\n\n```\nconfig :live_view_native_stylesheet,\n  annotations: false,\n  pretty: false\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Building a stylesheet rules parser - LiveViewNativeStylesheet","doc":"```elixir\ndefmodule MyCustomerRulesParser do\n  use LiveViewNative.Stylesheet.RulesParser, :swiftui\n\n  defmacro __using__(_) do\n    quote do\n      import MyCustomRulesParser, only: [sigil_RULES: 2]\n      import MyCustomRulesHelpers\n    end\n  end\n\n  def parse(rules) do\n    # your custom parser defined here\n  end\nend\n```\n\nThe `format` passed in during the `use` will define a new `sigil_RULES/2` function within\nyour customer parser. The `format` is carried through this function so make sure it matches\nthe `format` used for the sheet itself.\n\nYou *must* implement the `__using__/1` macro and at least `import` `sigil_RULES/2` from your\ncustom parser. `sigil_RULES/2` is injected into your module from `LiveViewNative.Stylesheet.RulesParser`.\nThis is also a good place to include other `import`s that are necessary to support the compilation of\nthe final stylsheet. In the example above `import MyCustomRulesHelpers` may include additional helpers\navailable to your parser's rule set.\n\nYou *must* implement the `parse/1` function as this is your primary hook for parsing the rules\nfound within the body of each class from the sheet","ref":"readme.html#building-a-stylesheet-rules-parser"},{"type":"extras","title":"Writing stylesheets - LiveViewNativeStylesheet","doc":"New stylesheets can be defined specific to each platform.\n\nNote that variable interpolation is done with `{ }` within the rules.\n\n```elixir\ndefmodule MySheet do\n  use LiveViewNative.Stylesheet, :swiftui\n\n  ~SHEET\"\"\"\n  \"color-\" <> color_name do\n    color(.{color_name})\n  end\n  \"\"\"\n\n  def class(\"color-\" <> color_name) do\n    ~RULES\"\"\"\n    color(.{color_name})\n    \"\"\"\n  end\n\n  def class(\"star-red\") do\n    ~RULES\"\"\"\n    background(alignment: .leading){:star-red}\n    \"\"\"\n  end\n\n  def class(\"star-blue\") do\n    ~RULES\"\"\"\n    background(alignment: .trailing){:star-blue}\n    \"\"\"\n  end\nend\n```","ref":"readme.html#writing-stylesheets"},{"type":"extras","title":"Compiling stylesheets - LiveViewNativeStylesheet","doc":"Stylesheets output only exactly what class names are matched in the templates. This is true of pattern matched class names as well. This\nkeeps the output small lookups fast on the client.\n\nTo compile a stylesheet you simply provide a list of class names and a map of ASTs will be produced. Using `MySheet` from above:\n\n```elixir\nMySheet.compile_ast(~w[color-blue star-red])\n\n=> %{\n  \"color-blue\" => [{:color, [], [{:., [], [nil, :blue]}]}]    [[\"color\", [[\".blue\", :IME]], nil]]\n  \"star-red\" => [{:background, [], [[alignment: {:., [], [nil, :trailing]}, content: :\"star-red\"]]}]\n}\n```\n\nThis map will be sent to the client for looking up the styles at runtime and applying with little to no parsing on the client side:\n\n```heex\n \n  ABCDEF\n   \n \n```\n\nSome style/modifier values make more sense as attrs on the element itself. Custom parsers should\nsupport `attr(value)`:\n\n```elixir\ndef class(\"searchable\") do\n  ~RULES\"\"\"\n  searchable(placeholder: attr(placeholder))\n  \"\"\"\nend\n```\n\nThis will instruct the client to get the value from the element the class name matches on:\n\n```heex\n Hello, world! \n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#compiling-stylesheets"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}